@@ -8,8 +8,7 @@
 
 #include "../../dict/dictengine.h"
 #include <QObject>
-
-class QQuickWebEngineProfile;
+#include <QQuickWebEngineProfile>
 
 class DictObject : public QObject
 {
@@ -60,7 +59,6 @@ private Q_SLOTS:
     void slotDictErrorOccurred(QAbstractSocket::SocketError socketError, const QString &errorString);
 
 private:
-    QString m_source;
     QString m_dataEngineName;
     QString m_selectedDict;
 
