@@ -66,7 +66,7 @@ QMap<QString, Ion::ConditionIcons> UKMETIon::setupDayIconMappings() const
         {QStringLiteral("fog"), Mist},
         {QStringLiteral("foggy"), Mist},
         {QStringLiteral("tropical storm"), Thunderstorm},
-        {QStringLiteral("hazy"), NotAvailable},
+        {QStringLiteral("hazy"), Mist},
         {QStringLiteral("light shower"), Showers},
         {QStringLiteral("light rain shower"), Showers},
         {QStringLiteral("light rain showers"), Showers},
@@ -120,7 +120,7 @@ QMap<QString, Ion::ConditionIcons> UKMETIon::setupNightIconMappings() const
         {QStringLiteral("fog"), Mist},
         {QStringLiteral("foggy"), Mist},
         {QStringLiteral("tropical storm"), Thunderstorm},
-        {QStringLiteral("hazy"), NotAvailable},
+        {QStringLiteral("hazy"), Mist},
         {QStringLiteral("light shower"), Showers},
         {QStringLiteral("light rain shower"), Showers},
         {QStringLiteral("light rain showers"), Showers},
