@@ -9,14 +9,14 @@
 
 #include <KRunner/AbstractRunner>
 
-using namespace Plasma;
+using namespace KRunner;
 
 class CharacterRunner : public AbstractRunner
 {
     Q_OBJECT
 
 public:
-    CharacterRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    CharacterRunner(QObject *parent, const KPluginMetaData &metaData);
     ~CharacterRunner() override;
 
     void reloadConfiguration() override;
