@@ -9,14 +9,14 @@
 #include "../../dict/dictengine.h"
 #include <KRunner/AbstractRunner>
 
-using namespace Plasma;
+using namespace KRunner;
 
 class DictionaryRunner : public AbstractRunner
 {
     Q_OBJECT
 
 public:
-    explicit DictionaryRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    explicit DictionaryRunner(QObject *parent, const KPluginMetaData &metaData);
     void match(RunnerContext &context) override;
     void run(const RunnerContext &context, const QueryMatch &match) override;
     void reloadConfiguration() override;
